import { PageResult, PageParams } from './common';

export interface SchoolItem {
  id: number;
  // 学校名称
  name: string;
  // 学校代码
  code: string;
  // 子机构代码
  subCode: string;
  // 开启双评
  doubleTrack: boolean;
  // 开启删除分组警告
  groupDeleteWarn: boolean;
  // 省份
  province: string;
  // 城市
  city: string;
  // 学校地址
  address: string;
  // 管理员登录名
  adminLoginName: string;
  // 管理员名称
  adminName: string;
  // 访问key
  accessKey: string;
  // 访问secret
  accessSecret: string;
  // 描述
  description: string;
}
export interface SchoolListFilter {
  name: string;
}
export type SchoolListPageParam = PageParams<SchoolListFilter>;
export type SchoolListPageRes = PageResult<SchoolItem>;

export type SchoolUpdateParam = Partial<SchoolItem>;

export interface SchoolUpdateAdminParam {
  id: number;
  // 管理员登录名
  adminLoginName: string;
  // 管理员名称
  adminName: string;
  // 密码
  password: string;
}

// set
export interface SettingItem {
  id: string | number; // 假设配置项有唯一ID
  // 配置项类型
  type: string;
  // 配置项值
  description: string | boolean | number;
  // 配置项key
  key: string; // 后端可能用key来区分配置项
}

// auth
export interface AuthInfo {
  // 是否授权
  auth: boolean;
  // 过期时间
  expireTime: string | null;
  // 授权模式
  authMode: string;
  // 是否开始双评
  doubleTrack: boolean;
  // 开启删除分组警告
  groupDeleteWarn: boolean;
  // 试评模式
  trialMode: string;
  // 支持客观题卡
  yjsObjectiveEnable: boolean;
}

export interface AuthUpdateParams {
  // 授权模式
  authMode: 'offline' | 'online' | '';
  // 授权文件
  offlineFile: File | null;
  // 访问key
  accessKey: string;
  // 访问secret
  accessSecret: string;
}
